#! /usr/bin/env python
import sys

from scrib import barf, cfg

try:
	import redis
except:
	barf.Barf('ERR', 'Please install redis module for python.')
	sys.exit()


class Db:
	def __init__(self):
		self.settings = cfg.set()
		# Don't set defaults here.
		self.settings.load('scrib.cfg', {}, suppress=True)
		self.barf = barf.Barf

		# Database vars
		self.host = self.settings.host
		self.port = self.settings.port
		self.tries = 0
		self.max_tries = 2
		self.prefix = 'scrib'  # Connect to Scrib Collective

		self.redis = self.check(self.host, self.port)

	def check(self, host='localhost', port='6379'):
		# Database check
		db = redis.Redis(host, port)
		return db  # Debug
		# See if redis server is running
		try:
			ping = db.ping()
			if ping is not True:
				self.barf('ERR', 'Redis server is not running.')
				self.barf('ERR', 'Please install and run it, then try again.')
				sys.exit()
			else:
				self.barf('ACT', 'Connection to %s started' % host)
				return db
		except Exception as e:
			self.barf('ERR', e)
			self.tries += 1

		while self.tries < self.max_tries:
			self.check(self.settings.host, self.settings.port)
		else:
			self.barf('ERR', 'No redis server found.')
			self.barf('ACT', 'Please make sure it is started or your host is correct.')
			sys.exit()

	def add(self, key, words):
		"""
		Nicely wrap redis sadd
		"""
		if self.settings.debug is 1:
			self.barf('DBG', 'db.add: %s' % key)
		self.redis.sadd(self._make_key(key), words[-1])

	def get_random(self, key):
		if self.settings.debug is 1:
			self.barf('DBG', 'db.get_random: %s' % key)
		return self.redis.srandmember(self._make_key(key))

	def _make_key(self, k):
		if self.settings.debug is 1:
			self.barf('DBG', 'db._make_key fired.')
		return '-'.join((self.prefix, k))
